import{O as r}from"./workspaceStore.3db35d66.js";import{d as l,X as i,o as u,Y as c,b as t,w as o,u as n,aG as d,dd as f,dc as _}from"./index.f642553c.js";import"./url.805125a0.js";import"./colorHelpers.05cd19a2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a7a2da42-d3ac-44aa-acab-5890729e5f8e",e._sentryDebugIdIdentifier="sentry-dbid-a7a2da42-d3ac-44aa-acab-5890729e5f8e")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(a,s)=>(u(),c("div",null,[t(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),t(n(_),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.07931152.js.map
