import{B as c}from"./BookOutlined.4710a705.js";import{d,o as a,c as l,w as o,b as f,u as n,$ as u,Y as i,aG as p,aS as b,bT as y}from"./index.f642553c.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="45c90083-6940-4b66-a124-cc99196c6717",t._sentryDebugIdIdentifier="sentry-dbid-45c90083-6940-4b66-a124-cc99196c6717")}catch{}})();const g=d({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return a(),l(n(y),{class:"docs-button",href:`https://abstra.io/docs/${(s=e.path)!=null?s:""}`,target:"_blank",type:"text",size:"small"},{icon:o(()=>[f(n(c))]),default:o(()=>[e.$slots.default?u(e.$slots,"default",{key:0}):(a(),i(b,{key:1},[p("Docs")],64))]),_:3},8,["href"])}}});export{g as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.deb30b56.js.map
