import{d as i,o as p,c as a,w as n,b as m,u as t}from"./index.f642553c.js";import"./linters.8d7e557c.js";import{W as s}from"./workspaces.9711e425.js";import{C as d}from"./ContentLayout.1ad8bab7.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.16431213.js";import"./asyncComputed.47ff725c.js";import"./workspaceStore.3db35d66.js";import"./url.805125a0.js";import"./colorHelpers.05cd19a2.js";import"./record.f177349f.js";import"./gateway.d1732116.js";import"./popupNotifcation.040c54ab.js";import"./fetch.ce6568e3.js";import"./SaveButton.32fabddc.js";import"./UnsavedChangesHandler.f5c0064d.js";import"./ExclamationCircleOutlined.a05b41a9.js";import"./CrudView.02c28fb9.js";import"./router.cd0be8d6.js";import"./Badge.7cb0aad6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.deb30b56.js";import"./BookOutlined.4710a705.js";import"./PhDotsThreeVertical.vue.c5095cdb.js";import"./index.1e400325.js";import"./index.3b613af3.js";import"./polling.3df437e7.js";import"./PhPencil.vue.b96803a2.js";import"./index.b05aadfa.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="81fa7487-5659-425a-a51f-ade9b21c3ae7",o._sentryDebugIdIdentifier="sentry-dbid-81fa7487-5659-425a-a51f-ade9b21c3ae7")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),a(d,null,{default:n(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.ca3e6aeb.js.map
