import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.16431213.js";import{d as i,ea as s,o as m,c as a,u as d}from"./index.f642553c.js";import"./gateway.d1732116.js";import"./popupNotifcation.040c54ab.js";import"./fetch.ce6568e3.js";import"./record.f177349f.js";import"./SaveButton.32fabddc.js";import"./UnsavedChangesHandler.f5c0064d.js";import"./ExclamationCircleOutlined.a05b41a9.js";import"./CrudView.02c28fb9.js";import"./router.cd0be8d6.js";import"./Badge.7cb0aad6.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.deb30b56.js";import"./BookOutlined.4710a705.js";import"./url.805125a0.js";import"./PhDotsThreeVertical.vue.c5095cdb.js";import"./index.1e400325.js";import"./index.3b613af3.js";import"./asyncComputed.47ff725c.js";import"./polling.3df437e7.js";import"./PhPencil.vue.b96803a2.js";import"./index.b05aadfa.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="17839df9-a49c-43f1-b0db-34924be15f11",o._sentryDebugIdIdentifier="sentry-dbid-17839df9-a49c-43f1-b0db-34924be15f11")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(f,c)=>(m(),a(n,{"env-var-repository":d(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.d9adcc23.js.map
