import{_ as p}from"./TasksView.vue_vue_type_script_setup_true_lang.1edef57a.js";import{L as c}from"./tasksController.64b17003.js";import{d,e as u,o as _,c as m,w as t,b as s,u as o,dd as y,aG as i,bT as b,dh as k,a0 as w}from"./index.f642553c.js";import{C as T}from"./ContentLayout.1ad8bab7.js";import{a as g}from"./ant-design.84179dee.js";import"./metadata.0475adf2.js";import"./PhRobot.vue.c534f639.js";import"./PhWebhooksLogo.vue.39c71176.js";import"./string.df9f642e.js";import"./dayjs.dc7e3364.js";import"./index.1e400325.js";import"./gateway.d1732116.js";import"./popupNotifcation.040c54ab.js";import"./scripts.5b11ab0e.js";import"./record.f177349f.js";import"./linters.8d7e557c.js";import"./asyncComputed.47ff725c.js";import"./polling.3df437e7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ae672d5b-f38b-404c-b71f-077e40eeaf16",e._sentryDebugIdIdentifier="sentry-dbid-ae672d5b-f38b-404c-b71f-077e40eeaf16")}catch{}})();const x=d({__name:"Tasks",setup(e){const a=new c,r=u(null);async function l(){var n;await g("Are you sure you want to clear all tasks and their associated payloads?")&&await((n=r.value)==null?void 0:n.clearAllTasks())}return(f,n)=>(_(),m(T,null,{default:t(()=>[s(o(k),{justify:"space-between",align:"center"},{default:t(()=>[s(o(y),null,{default:t(()=>[i("Tasks")]),_:1}),s(o(b),{type:"link",style:{"margin-top":"10px"},onClick:l},{default:t(()=>[i("Clear all")]),_:1})]),_:1}),s(p,{ref_key:"tasksTableView",ref:r,class:"tasks",api:o(a),stages:null,editor:""},null,8,["api"])]),_:1}))}});const H=w(x,[["__scopeId","data-v-4b92e2a9"]]);export{H as default};
//# sourceMappingURL=Tasks.0fbc5609.js.map
