import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.1edef57a.js";import{R as f}from"./tasksController.64b17003.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as d,c as I,S as T,aS as v,aG as B,dd as S}from"./index.f642553c.js";import"./gateway.d1732116.js";import{a as j,B as x}from"./build.3a323fca.js";import{a as C}from"./project.5bd3569c.js";import"./tables.80f07e68.js";import{a as D}from"./asyncComputed.47ff725c.js";import"./metadata.0475adf2.js";import"./PhRobot.vue.c534f639.js";import"./PhWebhooksLogo.vue.39c71176.js";import"./ant-design.84179dee.js";import"./string.df9f642e.js";import"./dayjs.dc7e3364.js";import"./index.1e400325.js";import"./scripts.5b11ab0e.js";import"./record.f177349f.js";import"./linters.8d7e557c.js";import"./polling.3df437e7.js";import"./popupNotifcation.040c54ab.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="4d60d436-b41b-473b-894d-db8e7176f068",e._sentryDebugIdIdentifier="sentry-dbid-4d60d436-b41b-473b-894d-db8e7176f068")}catch{}})();const U=b({__name:"Tasks",setup(e){const s=_().params.projectId,l=new f(s),{result:o}=D(async()=>{const r=(await j.list(s)).find(c=>c.latest);if(!r)return null;const[p,u]=await Promise.all([x.get(r.id),C.get(s)]);return{buildSpec:p,project:u}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(d(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:d(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{U as default};
//# sourceMappingURL=Tasks.c3feacd8.js.map
