import{k as i,T as n,m as r,P as o,C as p,M as c,s as d,n as s,p as m,q as u,t as b,v as f}from"./index.f642553c.js";import{s as g,c as y,a}from"./workspaceStore.3db35d66.js";import{_ as l}from"./App.vue_vue_type_style_index_0_lang.fb345eab.js";import"./url.805125a0.js";import"./colorHelpers.05cd19a2.js";import"./PlayerConfigProvider.8097f9fc.js";import"./index.a46330a5.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="b5871c9b-062a-4397-abec-285927606eab",t._sentryDebugIdIdentifier="sentry-dbid-b5871c9b-062a-4397-abec-285927606eab")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await g();const t=y(),e=i({render:()=>m(l)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",c),e.component("Message",d),s(e,u),s(e,b),s(e,f)})();
//# sourceMappingURL=player.491d2cd9.js.map
