import{d as t,o as d,Y as o,b as s,u as r,by as _,a0 as c}from"./index.f642553c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="fd9ed97e-1429-4a3c-8d6e-02aeb85661ab",e._sentryDebugIdIdentifier="sentry-dbid-fd9ed97e-1429-4a3c-8d6e-02aeb85661ab")}catch{}})();const i={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(d(),o("div",i,[s(r(_))]))}});const u=c(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.006778db.js.map
