import{a0 as t,r as c,o as s,c as r}from"./index.f642553c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a54f349c-ca64-4180-9fd2-1959e88a57a0",e._sentryDebugIdIdentifier="sentry-dbid-a54f349c-ca64-4180-9fd2-1959e88a57a0")}catch{}})();const a={};function _(e,o){const n=c("RouterView");return s(),r(n,{class:"router"})}const f=t(a,[["render",_],["__scopeId","data-v-3c2b9654"]]);export{f as default};
//# sourceMappingURL=Home.b755ee13.js.map
