import{O as r}from"./workspaceStore.3db35d66.js";import{d as i,X as l,o as u,Y as c,b as t,w as n,u as o,aG as s,dd as f,dc as b}from"./index.f642553c.js";import"./url.805125a0.js";import"./colorHelpers.05cd19a2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="11a44894-0bdb-40b4-8220-aa9a3c094965",e._sentryDebugIdIdentifier="sentry-dbid-11a44894-0bdb-40b4-8220-aa9a3c094965")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(a,d)=>(u(),c("div",null,[t(o(f),null,{default:n(()=>[s("You're authenticated")]),_:1}),t(o(b),null,{default:n(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.c3e5eed2.js.map
