import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.b48824db.js";import{d as m,eo as b,ea as f,o as g,Y as y,b as w,u as n,a0 as k}from"./index.f642553c.js";import{u as h}from"./workspaceStore.3db35d66.js";import"./Logo.6ff63c47.js";import"./string.df9f642e.js";import"./OTPInput.46e43e57.js";import"./index.b05aadfa.js";import"./url.805125a0.js";import"./colorHelpers.05cd19a2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="b231a755-79e4-4760-bb07-4e3c8b1366bf",e._sentryDebugIdIdentifier="sentry-dbid-b231a755-79e4-4760-bb07-4e3c8b1366bf")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=b(),t=f(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var c,u,p,d,i;return g(),y("div",v,[w(l,{"logo-url":(u=(c=n(r).state.workspace)==null?void 0:c.logoUrl)!=null?u:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(d=n(r).state.workspace)==null?void 0:d.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const C=k(I,[["__scopeId","data-v-cb33c596"]]);export{C as default};
//# sourceMappingURL=Login.7114d321.js.map
